import sys
from qt import *
from kdecore import *
import dcop
import dcopext
from dcopexport import DCOPExObj
from mainwindow import MainWindow

class Receiver(DCOPExObj):
    def __init__(self, translator):
        DCOPExObj.__init__(self, "TranslatorClient")

        self.addMethod("void translation(QString)", self.translation);

        self.translator = translator

    def translation(self, text):
        self.translator.translation(text)

class TranslatorClient(MainWindow):
    def __init__(self, dcopClient):
        MainWindow.__init__(self)
        self.dcop = dcopClient

        self.languages = dict()
        self.languages["English"] = "en"
        self.languages["German"]  = "de"
        self.languages["Spanish"] = "es"

        for key in self.languages.keys():
            self.cbFrom.insertItem(key)
            self.cbTo.insertItem(key)

        self.connect(self.btnTranslate, SIGNAL("clicked()"), self.translate)
        self.connect(self.btnToClipboard, SIGNAL("clicked()"), self.toClipboard)

        self.translationServer = dcopext.DCOPObj("googletranslator", self.dcop, \
                                                 "GoogleTranslator")
        self.klipper = dcopext.DCOPObj("klipper", self.dcop, "klipper")
        self.dcopRef = dcop.DCOPRef(self.dcop.appId(), "TranslationClient")

    def translate(self):
        langFrom = self.cbFrom.currentText()
        langTo   = self.cbTo.currentText()
        direction = self.languages[str(langFrom)] + "|"  + self.languages[str(langTo)]
        #self.translationServer.translate(self.edInput.text(), direction, self.dcopRef)
        self.translationServer.translate(self.edInput.text(), direction, \
                                         self.dcop.appId(), "TranslatorClient")

    def toClipboard(self):
        self.klipper.setClipboardContents(self.edOutput.text())

    def translation(self, text):
        self.edOutput.setText(text)

about = KAboutData("translatorclient", "Translator Client", "0.1",
                   "Python client for the googletranslator DCOP service",
                   KAboutData.License_GPL)

KCmdLineArgs.init(sys.argv, about)
app = KApplication()

translator = TranslatorClient(app.dcopClient())
receiver = Receiver(translator)
translator.setCaption(app.makeStdCaption("Google Translation Client"))
app.setMainWidget(translator)
translator.show()
app.exec_loop()
