require 'mainwindow.rb'

class Receiver < KDE::DCOPObject
    k_dcop 'void translation(QString)'

    def initialize(translator)
        super('TranslatorClient')
        @translator = translator
    end

    def translation(text)
        @translator.translation(text)
    end
end

class TranslatorClient < MainWindow
    slots 'toClipboard()', 'translate()'
    def initialize(parent = nil)
        super

        @languages = Hash.new
        @languages['English'] = 'en'
        @languages['German']  = 'de'
        @languages['Spanish'] = 'es'

        keys = @languages.keys
        @cbFrom.insertStringList(keys)
        @cbTo.insertStringList(keys)

        connect(@btnToClipboard, SIGNAL('clicked()'), self, SLOT('toClipboard()'))
        connect(@btnTranslate,   SIGNAL('clicked()'), self, SLOT('translate()'))

        @translationServer = KDE::DCOPRef.new("googletranslator", "GoogleTranslator")
        @dcopSelf = KDE::DCOPRef.new("translatorclient-%d" % $$, "TranslatorClient")
        @klipper = KDE::DCOPRef.new("klipper", "klipper")
    end

    def translate
        direction = @languages[@cbFrom.currentText] + '|' + @languages[@cbTo.currentText]
        @translationServer.translate(@edInput.text, direction, @dcopSelf.app, @dcopSelf.obj)
    end

    def toClipboard
        @klipper.setClipboardContents(@edOutput.text)
    end

    def translation(text)
        @edOutput.text = text
    end
end

about = KDE::AboutData.new("translatorclient", "Translator Client", "0.1",
                           "Ruby client for the googletranslator DCOP service",
                           KDE::AboutData::License_GPL)
about.addAuthor("Richard Dale",  "Creator")
about.addAuthor("Kevin Krammer", "Developer", "kevin.krammer@gmx.at")

KDE::CmdLineArgs.init(ARGV, about)
app = KDE::Application.new
translator = TranslatorClient.new
receiver = Receiver.new(translator)
app.mainWidget = translator
#translator.caption = app.makeStdCaption("Google Translation Client")
translator.caption = "Google Translation Client"
translator.show
app.exec
